@@ -264,13 +264,14 @@ def build_golang_repo_url(purl):
     """
     purl_data = PackageURL.from_string(purl)
 
+    namespace = purl_data.namespace
     name = purl_data.name
     version = purl_data.version
 
     if name and version:
-        return f"https://pkg.go.dev/{name}@{version}"
+        return f"https://pkg.go.dev/{namespace}/{name}@{version}"
     elif name:
-        return f"https://pkg.go.dev/{name}"
+        return f"https://pkg.go.dev/{namespace}/{name}"
 
 
 # Download URLs:
